==> fiboa_cli-0.5.0.tar.gz: fiboa_cli-0.5.0/fiboa_cli/datasets/de_sh.py <==
from ..convert_utils import convert as convert_

SOURCES = "https://service.gdi-sh.de/SH_OpenGBD/feeds/Atom_SH_Feldblockfinder_OpenGBD/data/Feldbloecke_2024_GPKG.zip"
ID = "de_sh"
TITLE = "Field boundaries for Schleswig-Holstein (SH), Germany"
DESCRIPTION = """A field block (German: "Feldblock") is a contiguous agricultural area surrounded by permanent boundaries, which is cultivated by one or more farmers with one or more crops, is fully or partially set aside or is fully or partially taken out of production."""
PROVIDER_NAME = "Land Schleswig-Holstein"
PROVIDER_URL = "https://sh-mis.gdi-sh.de/catalog/#/datasets/iso/21f67269-780f-4f3c-8f66-03dde27acfe7"
LICENSE = "dl-de/zero-2-0"
# From http://osmtipps.lefty1963.de/2008/10/bundeslnder.html
BBOX = [7.8685145620,53.3590675115,11.3132037822,55.0573747014]
EXTENSIONS = [
    "https://fiboa.github.io/flik-extension/v0.1.0/schema.yaml"
]
COLUMNS = {
    'geometry': 'geometry',
    'fachguelti': 'determination_datetime',
    'FLIK': ['flik', 'id'], # make flik id a dedicated column to align with NRW etc.
    'Flaeche': 'area',
    'HBN': 'hbn'
}
MISSING_SCHEMAS = {
    'properties': {
        'hbn': {
            'type': 'string'
        }
    }
}

def convert(output_file, cache = None, source_coop_url = None, collection = False, compression = None):
    """
    Converts the Schleswig-Holstein (Germany) field boundary datasets to fiboa.
    """
    convert_(
        output_file, cache,
        SOURCES, COLUMNS, ID, TITLE, DESCRIPTION, BBOX,
        extensions=EXTENSIONS,
        missing_schemas=MISSING_SCHEMAS,
        license=LICENSE,
        source_coop_url=source_coop_url,
        provider_name=PROVIDER_NAME,
        provider_url=PROVIDER_URL,
        store_collection=collection,
        compression=compression,
    )

==> fiboa_cli-0.8.0.tar.gz: fiboa_cli-0.8.0/fiboa_cli/datasets/de_sh.py <==
from ..convert_utils import convert as convert_

SOURCES = "https://service.gdi-sh.de/SH_OpenGBD/feeds/Atom_SH_Feldblockfinder_OpenGBD/data/Feldbloecke_2024_GPKG.zip"
ID = "de_sh"
SHORT_NAME = "Germany, Schleswig-Holstein"
TITLE = "Field boundaries for Schleswig-Holstein (SH), Germany"
DESCRIPTION = """A field block (German: "Feldblock") is a contiguous agricultural area surrounded by permanent boundaries, which is cultivated by one or more farmers with one or more crops, is fully or partially set aside or is fully or partially taken out of production."""
PROVIDERS = [
    {
        "name": "Land Schleswig-Holstein",
        "url": "https://sh-mis.gdi-sh.de/catalog/#/datasets/iso/21f67269-780f-4f3c-8f66-03dde27acfe7",
        "roles": ["producer", "licensor"]
    }
]
LICENSE = "dl-de/zero-2-0"
EXTENSIONS = [
    "https://fiboa.github.io/flik-extension/v0.1.0/schema.yaml"
]
COLUMNS = {
    'geometry': 'geometry',
    'fachguelti': 'determination_datetime',
    'FLIK': ['flik', 'id'], # make flik id a dedicated column to align with NRW etc.
    'Flaeche': 'area',
    'HBN': 'hbn'
}
MISSING_SCHEMAS = {
    'properties': {
        'hbn': {
            'type': 'string'
        }
    }
}

def convert(output_file, cache = None, **kwargs):
    """
    Converts the Schleswig-Holstein (Germany) field boundary datasets to fiboa.
    """
    convert_(
        output_file, cache,
        SOURCES, COLUMNS, ID, TITLE, DESCRIPTION,
        extensions=EXTENSIONS,
        missing_schemas=MISSING_SCHEMAS,
        license=LICENSE,
        providers=PROVIDERS,
        **kwargs
    )
